//!
//! Configuration to initialize the Fenrir networking library

use ::std::{
    net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr},
    num::NonZeroUsize,
    option::Option,
    vec,
};

/// Main config for libFenrir
#[derive(Clone, Debug)]
pub struct Config {
    /// number of threads that libFenrir will use
    pub threads: Option<NonZeroUsize>,
    /// List of ipv4 or ipv6 UDP inet socket to listen on
    /// If empty, libFenrir will listen on a random UDP port on `0.0.0.0`
    pub listen: Vec<SocketAddr>,
    /// List of DNS resolvers to use
    pub resolvers: Vec<SocketAddr>,
}

impl Default for Config {
    fn default() -> Self {
        Config {
            threads: None,
            listen: vec![
                // ipv4 random port
                SocketAddr::new(IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)), 0),
                // ipv6 random port
                SocketAddr::new(
                    IpAddr::V6(Ipv6Addr::new(0, 0, 0, 0, 0, 0, 0, 0)),
                    0,
                ),
            ],
            resolvers: Vec::new(),
        }
    }
}
